# T3CO Documentation

[CodeFlow.md](CodeFlow.md)

[PHEVs.md](PHEVs.md)

[ScenarioFile.md](ScenarioFile.md)

[T3CO_Overview.md](T3CO_Overview.md)

[TCO_calculations.md](TCO_calculations.md)

[acceleration_and_grade_tests.md](acceleration_and_grade_tests.md)

[fuel_efficiency_and_range.md](fuel_efficiency_and_range.md)

[optimization.md](optimization.md)
